@@ -1,40 +1,28 @@
-/* -*- Mode: C; tab-width: 4 -*-
- *
+/*
  * Copyright (c) 1997-2004 Apple Computer, Inc. All rights reserved.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * @APPLE_LICENSE_HEADER_START@
  * 
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
+ * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
  * limitations under the License.
+ * 
+ * @APPLE_LICENSE_HEADER_END@
 
     Change History (most recent first):
     
 $Log: PrinterSetupWizardSheet.cpp,v $
-Revision 1.35  2006/08/14 23:24:09  cheshire
-Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
-
-Revision 1.34  2005/10/05 17:32:51  herscher
-<rdar://problem/4141221> Use a case insensitive compare operation to check whether a printer with the same name has already been installed.
-
-Revision 1.33  2005/07/11 20:17:15  shersche
-<rdar://problem/4124524> UI fixes associated with CUPS printer workaround fix.
-
-Revision 1.32  2005/07/07 17:53:20  shersche
-Fix problems associated with the CUPS printer workaround fix.
-
-Revision 1.31  2005/06/30 18:02:54  shersche
-<rdar://problem/4124524> Workaround for Mac OS X Printer Sharing bug
-
-Revision 1.30  2005/04/13 17:46:22  shersche
-<rdar://problem/4082122> Generic PCL not selected when printers advertise multiple text records
-
 Revision 1.29  2005/02/14 20:48:37  shersche
 <rdar://problem/4003710> Default pdl key to "application/postscript"
 
@@ -175,8 +163,7 @@ CPrinterSetupWizardSheet::CPrinterSetupWizardSheet(UINT nIDCaption, CWnd* pParen
 	m_driverThreadFinished( false ),
 	m_pdlBrowser( NULL ),
 	m_ippBrowser( NULL ),
-	m_lprBrowser( NULL ),
-	m_lastPage( NULL )
+	m_lprBrowser( NULL )
 {
 	m_arrow		=	LoadCursor(0, IDC_ARROW);
 	m_wait		=	LoadCursor(0, IDC_APPSTARTING);
@@ -258,7 +245,7 @@ CPrinterSetupWizardSheet::LoadPrinterNames()
 		{
 			PRINTER_INFO_4 * lppi4 = (PRINTER_INFO_4*) (buffer + index * sizeof(PRINTER_INFO_4));
 
-			m_printerNames.push_back( lppi4->pPrinterName );
+			m_printerNames[lppi4->pPrinterName] = lppi4->pPrinterName;
 		}
 	}
 
@@ -302,7 +289,6 @@ CPrinterSetupWizardSheet::InstallPrinter(Printer * printer)
 	//
 	// if the driver isn't installed, then install it
 	//
-
 	if ( !printer->driverInstalled )
 	{
 		DWORD		dwResult;
@@ -412,7 +398,7 @@ CPrinterSetupWizardSheet::InstallPrinterPDLAndLPR(Printer * printer, Service * s
 	ok = OpenPrinter(L",XcvMonitor Standard TCP/IP Port", &hXcv, &printerDefaults);
 	err = translate_errno( ok, errno_compat(), kUnknownErr );
 	require_noerr( err, exit );
-
+	
 	//
 	// BUGBUG: MSDN said this is not required, but my experience shows it is required
 	//
@@ -443,7 +429,7 @@ CPrinterSetupWizardSheet::InstallPrinterPDLAndLPR(Printer * printer, Service * s
 	wcscpy(portData.sztQueue, q->name);
 	wcscpy(portData.sztIPAddress, service->hostname); 
 	wcscpy(portData.sztHostAddress, service->hostname);
-
+		
 	ok = XcvData(hXcv, L"AddPort", (PBYTE) &portData, sizeof(PORT_DATA_1), pOutputData, cbInputData,  &cbOutputNeeded, &dwStatus);
 	err = translate_errno( ok, errno_compat(), kUnknownErr );
 	require_noerr( err, exit );
@@ -459,7 +445,7 @@ CPrinterSetupWizardSheet::InstallPrinterPDLAndLPR(Printer * printer, Service * s
 	pInfo.pPortName				=	printer->portName.GetBuffer();
 	pInfo.pDriverName			=	printer->modelName.GetBuffer();
 	pInfo.pComment				=	printer->displayModelName.GetBuffer();
-	pInfo.pLocation				=	q->location.GetBuffer();
+	pInfo.pLocation				=	service->location.GetBuffer();
 	pInfo.pDevMode				=	NULL;
 	pInfo.pDevMode				=	NULL;
 	pInfo.pSepFile				=	L"";
@@ -503,12 +489,9 @@ CPrinterSetupWizardSheet::InstallPrinterIPP(Printer * printer, Service * service
 {
 	DEBUG_UNUSED( service );
 
-	Queue		*	q		 = service->SelectedQueue();
 	HANDLE			hPrinter = NULL;
 	PRINTER_INFO_2	pInfo;
 	OSStatus		err;
-
-	check( q );
 	
 	//
 	// add the printer
@@ -519,7 +502,7 @@ CPrinterSetupWizardSheet::InstallPrinterIPP(Printer * printer, Service * service
 	pInfo.pPortName			= printer->portName.GetBuffer();
 	pInfo.pDriverName		= printer->modelName.GetBuffer();
 	pInfo.pPrintProcessor	= L"winprint";
-	pInfo.pLocation			= q->location.GetBuffer();
+	pInfo.pLocation			= service->location.GetBuffer();
 	pInfo.pComment			= printer->displayModelName.GetBuffer();
 	pInfo.Attributes		= PRINTER_ATTRIBUTE_NETWORK | PRINTER_ATTRIBUTE_LOCAL;
 	
@@ -903,6 +886,8 @@ CPrinterSetupWizardSheet::OnResolve(
 	CPrinterSetupWizardSheet	*	self;
 	Service						*	service;
 	Queue						*	q;
+	uint32_t						qpriority = kDefaultPriority;
+	CString							qname;
 	int								idx;
 	OSStatus						err;
 
@@ -940,6 +925,13 @@ CPrinterSetupWizardSheet::OnResolve(
 	//
 	service->portNumber = ntohs(inPort);
 
+	//
+	// parse the text record.
+	//
+
+	err = self->ParseTextRecord( service, inTXTSize, inTXT, qname, qpriority );
+	require_noerr( err, exit );
+
 	if ( service->qtotal == 1 )
 	{	
 		//
@@ -956,13 +948,10 @@ CPrinterSetupWizardSheet::OnResolve(
 
 		require_action( q, exit, err = E_OUTOFMEMORY );
 
-		//
-		// parse the text record.
-		//
-
-		err = self->ParseTextRecord( service, q, inTXTSize, inTXT );
-		require_noerr( err, exit );
 
+		q->name		= qname;
+		q->priority = qpriority;
+		
 		service->queues.push_back( q );
 
 		//
@@ -1044,7 +1033,7 @@ CPrinterSetupWizardSheet::OnQuery(
 
 		require_action( q, exit, err = E_OUTOFMEMORY );
 
-		err = service->printer->window->ParseTextRecord( service, q, inRDLen, inTXT );
+		err = service->printer->window->ParseTextRecord( service, inRDLen, inTXT, q->name, q->priority );
 		require_noerr( err, exit );
 
 		//
@@ -1132,18 +1121,9 @@ CPrinterSetupWizardSheet::OnAddPrinter(
 
 	for (;;)
 	{
-		CPrinterSetupWizardSheet::PrinterNames::iterator it;
+		CPrinterSetupWizardSheet::PrinterNameMap::iterator it;
 
-		// <rdar://problem/4141221> Don't use find to do comparisons because we need to
-		// do a case insensitive string comparison
-
-		for ( it = m_printerNames.begin(); it != m_printerNames.end(); it++ )
-		{
-			if ( (*it).CompareNoCase( printer->actualName ) == 0 )
-			{
-				break;
-			}
-		}
+		it = m_printerNames.find(printer->actualName);
 
 		if (it != m_printerNames.end())
 		{
@@ -1287,7 +1267,7 @@ CPrinterSetupWizardSheet::OnResolveService( Service * service )
 {
 	// Make sure that the active page is page 2
 
-	require_quiet( GetActivePage() == &m_pgSecond, exit );
+	check( GetActivePage() == &m_pgSecond );
 
 	if ( !--service->printer->resolving )
 	{
@@ -1309,10 +1289,6 @@ CPrinterSetupWizardSheet::OnResolveService( Service * service )
 
 		m_pgSecond.OnResolveService( service );
 	}		
-
-exit:
-
-	return;
 }
 
 
@@ -1536,11 +1512,8 @@ exit:
 
 
 OSStatus
-CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_t inTXTSize, const char * inTXT )
+CPrinterSetupWizardSheet::ParseTextRecord( Service * service, uint16_t inTXTSize, const char * inTXT, CString & qname, uint32_t & qpriority )
 {
-	check( service );
-	check( q );
-
 	// <rdar://problem/3946587> Use TXTRecord APIs declared in dns_sd.h
 	
 	bool			qtotalDefined	= false;
@@ -1551,11 +1524,11 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 
 	// <rdar://problem/3987680> Default to queue "lp"
 
-	q->name = L"lp";
+	qname = L"lp";
 
 	// <rdar://problem/4003710> Default pdl key to be "application/postscript"
 
-	q->pdl = L"application/postscript";
+	service->pdl = L"application/postscript";
 
 	if ( ( val = TXTRecordGetValuePtr( inTXTSize, inTXT, "rp", &len ) ) != NULL )
 	{
@@ -1564,7 +1537,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->name );
+		err = UTF8StringToStringObject( buf, qname );
 		require_noerr( err, exit );
 	}
 	
@@ -1575,7 +1548,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->pdl );
+		err = UTF8StringToStringObject( buf, service->pdl );
 		require_noerr( err, exit );
 	}
 	
@@ -1587,7 +1560,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->usb_MFG );
+		err = UTF8StringToStringObject( buf, service->usb_MFG );
 		require_noerr( err, exit );
 	}
 	
@@ -1599,7 +1572,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->usb_MDL );
+		err = UTF8StringToStringObject( buf, service->usb_MDL );
 		require_noerr( err, exit );
 	}
 
@@ -1610,7 +1583,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->description );
+		err = UTF8StringToStringObject( buf, service->description );
 		require_noerr( err, exit );
 	}
 		
@@ -1621,7 +1594,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->product );
+		err = UTF8StringToStringObject( buf, service->product );
 		require_noerr( err, exit );
 	}
 
@@ -1632,7 +1605,7 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		err = UTF8StringToStringObject( buf, q->location );
+		err = UTF8StringToStringObject( buf, service->location );
 		require_noerr( err, exit );
 	}
 
@@ -1654,27 +1627,20 @@ CPrinterSetupWizardSheet::ParseTextRecord( Service * service, Queue * q, uint16_
 		memcpy( buf, val, len );
 		buf[len] = '\0';
 
-		q->priority = atoi( buf );
-	}
-
-	// <rdar://problem/4124524> Was this printer discovered via OS X Printer Sharing?
-
-	if ( TXTRecordContainsKey( inTXTSize, inTXT, "printer-state" ) || TXTRecordContainsKey( inTXTSize, inTXT, "printer-type" ) )
-	{
-		service->printer->isSharedFromOSX = true;
+		qpriority = atoi( buf );
 	}
 
 exit:
 
 	// The following code is to fix a problem with older HP 
 	// printers that don't include "qtotal" in their text
-	// record.  We'll check to see if the q->name is "TEXT"
+	// record.  We'll check to see if the qname is "TEXT"
 	// and if so, we're going to modify it to be "lp" so
 	// that we don't use the wrong queue
 
-	if ( !err && !qtotalDefined && ( q->name == L"TEXT" ) )
+	if ( !err && !qtotalDefined && ( qname == L"TEXT" ) )
 	{
-		q->name = "lp";
+		qname = "lp";
 	}
 
 	return err;
