@@ -2,30 +2,28 @@
  *
  * Copyright (c) 2002-2004 Apple Computer, Inc. All rights reserved.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * @APPLE_LICENSE_HEADER_START@
  * 
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
+ * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
  * limitations under the License.
+ * 
+ * @APPLE_LICENSE_HEADER_END@
 
     Change History (most recent first):
 
 $Log: Responder.c,v $
-Revision 1.32  2006/08/14 23:24:46  cheshire
-Re-licensed mDNSResponder daemon source code under Apache License, Version 2.0
-
-Revision 1.31  2006/06/12 18:22:42  cheshire
-<rdar://problem/4580067> mDNSResponder building warnings under Red Hat 64-bit (LP64) Linux
-
-Revision 1.30  2005/10/26 22:21:16  cheshire
-<rdar://problem/4149841> Potential buffer overflow in mDNSResponderPosix
-
 Revision 1.29  2005/03/04 21:35:33  cheshire
 <rdar://problem/4037201> Services.txt file not parsed properly when it contains more than one service
 
@@ -593,7 +591,7 @@ static mStatus RegisterServicesInFile(const char *filePath)
 			const char *dom = kDefaultServiceDomain;
 			char rawText[1024];
 			mDNSu8  text[sizeof(RDataBody)];
-			unsigned int textLen = 0;
+			mDNSu16 textLen = 0;
 			char port[256];
 
             // Skip over any blank lines.
@@ -628,11 +626,10 @@ static mStatus RegisterServicesInFile(const char *filePath)
 					len = strlen(rawText);
 					if (len <= 255)
 						{
-						unsigned int newlen = textLen + 1 + len;
-						if (len == 0 || newlen >= sizeof(text)) break;
 						text[textLen] = len;
-						memcpy(text + textLen + 1, rawText, len);
-						textLen = newlen;
+						if (text[textLen] == 0) break;
+						memcpy(text + textLen + 1, rawText, text[textLen]);
+						textLen += 1 + text[textLen];
 						}
 					else
 						fprintf(stderr, "%s: TXT attribute too long for name = %s, type = %s, port = %s\n", 
@@ -831,7 +828,7 @@ int main(int argc, char **argv)
         result = 2;
     }
     if ( (result != 0) || (gMDNSPlatformPosixVerboseLevel > 0) ) {
-        fprintf(stderr, "%s: Finished with status %d, result %d\n", gProgramName, (int)status, result);
+        fprintf(stderr, "%s: Finished with status %ld, result %d\n", gProgramName, status, result);
     }
     
     return result;
